pytilities.geometry

Package pytilities :: Package geometry |
[hide private]
[frames] | no frames]

# Source Code for Package pytilities.geometry

     1  # Copyright (C) 2010 Tim Diels <limyreth@users.sourceforge.net>
     2  #
     3  # This file is part of pytilities.
     4  #
     5  # pytilities is free software: you can redistribute it and/or modify
     6  # it under the terms of the GNU General Public License as published by
     7  # the Free Software Foundation, either version 3 of the License, or
     8  # (at your option) any later version.
     9  #
    10  # pytilities is distributed in the hope that it will be useful,
    11  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    12  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    13  # GNU General Public License for more details.
    14  #
    15  # You should have received a copy of the GNU General Public License
    16  # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
    17  #
    18
    19  """
    20  All sorts of geometry trinkets
    21
    22  Classes:
    23
    24      `Vector`
    25          2D Point/Vector
    26
    27      `BoundVector`
    28          `Vector` whose x and y values are stored elsewhere.
    29
    30      `ImmutableVector`
    31          `Vector` wrapper that makes the vector immutable.
    32
    33      `VerboseVector`
    34          `Vector` wrapper that sends out events.
    35
    36      `Rectangle`
    37          A rectangle identified by two points.
    38
    39      `VerboseRectangle`
    40          `Rectangle` wrapper that sends out events
    41  """
    42
    43  __docformat__ = 'reStructuredText'
    44
    45  from .vector import Vector
    46  from .verbosevector import VerboseVector
    47  from .immutablevector import ImmutableVector
    48  from .boundvector import BoundVector
    49  from .rectangle import Rectangle
    50  from .verboserectangle import VerboseRectangle
    51